/* EnumerationTest.c generated by valac 0.34.6, the Vala compiler
 * generated from EnumerationTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */

#include <glib.h>
#include <glib-object.h>
#include <gxml/gxml.h>
#include <stdlib.h>
#include <string.h>
#include <stdio.h>


#define TYPE_OPTIONS_ENUM (options_enum_get_type ())

#define TYPE_OBJECT_MODEL (object_model_get_type ())
#define OBJECT_MODEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_OBJECT_MODEL, ObjectModel))
#define OBJECT_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_OBJECT_MODEL, ObjectModelClass))
#define IS_OBJECT_MODEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_OBJECT_MODEL))
#define IS_OBJECT_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_OBJECT_MODEL))
#define OBJECT_MODEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_OBJECT_MODEL, ObjectModelClass))

typedef struct _ObjectModel ObjectModel;
typedef struct _ObjectModelClass ObjectModelClass;
typedef struct _ObjectModelPrivate ObjectModelPrivate;

#define TYPE_OPTIONS (options_get_type ())
#define OPTIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_OPTIONS, Options))
#define OPTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_OPTIONS, OptionsClass))
#define IS_OPTIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_OPTIONS))
#define IS_OPTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_OPTIONS))
#define OPTIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_OPTIONS, OptionsClass))

typedef struct _Options Options;
typedef struct _OptionsClass OptionsClass;
typedef struct _OptionsPrivate OptionsPrivate;

#define OPTIONS_TYPE_VALUES (options_values_get_type ())
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_ENUMERATION_TEST (serializable_enumeration_test_get_type ())
#define SERIALIZABLE_ENUMERATION_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_ENUMERATION_TEST, SerializableEnumerationTest))
#define SERIALIZABLE_ENUMERATION_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_ENUMERATION_TEST, SerializableEnumerationTestClass))
#define IS_SERIALIZABLE_ENUMERATION_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_ENUMERATION_TEST))
#define IS_SERIALIZABLE_ENUMERATION_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_ENUMERATION_TEST))
#define SERIALIZABLE_ENUMERATION_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_ENUMERATION_TEST, SerializableEnumerationTestClass))

typedef struct _SerializableEnumerationTest SerializableEnumerationTest;
typedef struct _SerializableEnumerationTestClass SerializableEnumerationTestClass;
typedef struct _SerializableEnumerationTestPrivate SerializableEnumerationTestPrivate;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

typedef enum  {
	OPTIONS_ENUM_SelectBefore,
	OPTIONS_ENUM_HoldOn,
	OPTIONS_ENUM_LeaveHeare,
	OPTIONS_ENUM_NORMAL_OPERATION
} OptionsEnum;

struct _ObjectModel {
	GXmlSerializableObjectModel parent_instance;
	ObjectModelPrivate * priv;
};

struct _ObjectModelClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _Options {
	ObjectModel parent_instance;
	OptionsPrivate * priv;
};

struct _OptionsClass {
	ObjectModelClass parent_class;
};

typedef enum  {
	OPTIONS_VALUES_AP,
	OPTIONS_VALUES_KP_VALUE,
	OPTIONS_VALUES_EXTERNAL_VALUE_VISION
} OptionsValues;

struct _OptionsPrivate {
	gchar* _test;
	OptionsEnum _options;
	OptionsValues _vals;
};

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializableEnumerationTest {
	GXmlTest parent_instance;
	SerializableEnumerationTestPrivate * priv;
};

struct _SerializableEnumerationTestClass {
	GXmlTestClass parent_class;
};


static gpointer options_parent_class = NULL;
static gpointer serializable_enumeration_test_parent_class = NULL;

GType options_enum_get_type (void) G_GNUC_CONST;
GType object_model_get_type (void) G_GNUC_CONST;
GType options_get_type (void) G_GNUC_CONST;
GType options_values_get_type (void) G_GNUC_CONST;
#define OPTIONS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_OPTIONS, OptionsPrivate))
enum  {
	OPTIONS_DUMMY_PROPERTY,
	OPTIONS_TEST,
	OPTIONS_OPTIONS,
	OPTIONS_VALS
};
Options* options_new (void);
Options* options_construct (GType object_type);
ObjectModel* object_model_new (void);
ObjectModel* object_model_construct (GType object_type);
const gchar* options_get_test (Options* self);
void options_set_test (Options* self, const gchar* value);
OptionsEnum options_get_options (Options* self);
void options_set_options (Options* self, OptionsEnum value);
OptionsValues options_get_vals (Options* self);
void options_set_vals (Options* self, OptionsValues value);
static void options_finalize (GObject* obj);
static void _vala_options_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_options_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_gxml_test (GValue* value, gpointer v_object);
void value_take_gxml_test (GValue* value, gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_enumeration_test_get_type (void) G_GNUC_CONST;
enum  {
	SERIALIZABLE_ENUMERATION_TEST_DUMMY_PROPERTY
};
void serializable_enumeration_test_add_tests (void);
static void __lambda77_ (void);
const gchar* options_enum_to_string (OptionsEnum self);
static void ___lambda77__gtest_func (void);
static void __lambda78_ (void);
static void ___lambda78__gtest_func (void);
static void __lambda79_ (void);
static void ___lambda79__gtest_func (void);
static void __lambda80_ (void);
static void ___lambda80__gtest_func (void);
static void __lambda81_ (void);
static void ___lambda81__gtest_func (void);
SerializableEnumerationTest* serializable_enumeration_test_new (void);
SerializableEnumerationTest* serializable_enumeration_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


/**
 *
 *  GXml.EnumerationTest
 *
 *  Authors:
 *
 *       Daniel Espinosa <esodan@gmail.com>
 *
 *
 *  Copyright (c) 2013-2015 Daniel Espinosa
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
GType options_enum_get_type (void) {
	static volatile gsize options_enum_type_id__volatile = 0;
	if (g_once_init_enter (&options_enum_type_id__volatile)) {
		static const GEnumValue values[] = {{OPTIONS_ENUM_SelectBefore, "OPTIONS_ENUM_SelectBefore", "selectbefore"}, {OPTIONS_ENUM_HoldOn, "OPTIONS_ENUM_HoldOn", "holdon"}, {OPTIONS_ENUM_LeaveHeare, "OPTIONS_ENUM_LeaveHeare", "leaveheare"}, {OPTIONS_ENUM_NORMAL_OPERATION, "OPTIONS_ENUM_NORMAL_OPERATION", "normal-operation"}, {0, NULL, NULL}};
		GType options_enum_type_id;
		options_enum_type_id = g_enum_register_static ("OptionsEnum", values);
		g_once_init_leave (&options_enum_type_id__volatile, options_enum_type_id);
	}
	return options_enum_type_id__volatile;
}


GType options_values_get_type (void) {
	static volatile gsize options_values_type_id__volatile = 0;
	if (g_once_init_enter (&options_values_type_id__volatile)) {
		static const GEnumValue values[] = {{OPTIONS_VALUES_AP, "OPTIONS_VALUES_AP", "ap"}, {OPTIONS_VALUES_KP_VALUE, "OPTIONS_VALUES_KP_VALUE", "kp-value"}, {OPTIONS_VALUES_EXTERNAL_VALUE_VISION, "OPTIONS_VALUES_EXTERNAL_VALUE_VISION", "external-value-vision"}, {0, NULL, NULL}};
		GType options_values_type_id;
		options_values_type_id = g_enum_register_static ("OptionsValues", values);
		g_once_init_leave (&options_values_type_id__volatile, options_values_type_id);
	}
	return options_values_type_id__volatile;
}


Options* options_construct (GType object_type) {
	Options * self = NULL;
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	self = (Options*) object_model_construct (object_type);
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	return self;
#line 240 "EnumerationTest.c"
}


Options* options_new (void) {
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	return options_construct (TYPE_OPTIONS);
#line 247 "EnumerationTest.c"
}


const gchar* options_get_test (Options* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 40 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 40 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	_tmp0_ = self->priv->_test;
#line 40 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	result = _tmp0_;
#line 40 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	return result;
#line 262 "EnumerationTest.c"
}


void options_set_test (Options* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 40 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	g_return_if_fail (self != NULL);
#line 40 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	_tmp0_ = value;
#line 40 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 40 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	_g_free0 (self->priv->_test);
#line 40 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	self->priv->_test = _tmp1_;
#line 40 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	g_object_notify ((GObject *) self, "test");
#line 281 "EnumerationTest.c"
}


OptionsEnum options_get_options (Options* self) {
	OptionsEnum result;
	OptionsEnum _tmp0_ = 0;
#line 41 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 41 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	_tmp0_ = self->priv->_options;
#line 41 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	result = _tmp0_;
#line 41 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	return result;
#line 296 "EnumerationTest.c"
}


void options_set_options (Options* self, OptionsEnum value) {
	OptionsEnum _tmp0_ = 0;
#line 41 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	g_return_if_fail (self != NULL);
#line 41 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	_tmp0_ = value;
#line 41 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	self->priv->_options = _tmp0_;
#line 41 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	g_object_notify ((GObject *) self, "options");
#line 310 "EnumerationTest.c"
}


OptionsValues options_get_vals (Options* self) {
	OptionsValues result;
	OptionsValues _tmp0_ = 0;
#line 42 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 42 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	_tmp0_ = self->priv->_vals;
#line 42 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	result = _tmp0_;
#line 42 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	return result;
#line 325 "EnumerationTest.c"
}


void options_set_vals (Options* self, OptionsValues value) {
	OptionsValues _tmp0_ = 0;
#line 42 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	g_return_if_fail (self != NULL);
#line 42 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	_tmp0_ = value;
#line 42 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	self->priv->_vals = _tmp0_;
#line 42 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	g_object_notify ((GObject *) self, "vals");
#line 339 "EnumerationTest.c"
}


static void options_class_init (OptionsClass * klass) {
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	options_parent_class = g_type_class_peek_parent (klass);
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	g_type_class_add_private (klass, sizeof (OptionsPrivate));
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_options_get_property;
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_options_set_property;
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = options_finalize;
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), OPTIONS_TEST, g_param_spec_string ("test", "test", "test", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), OPTIONS_OPTIONS, g_param_spec_enum ("options", "options", "options", TYPE_OPTIONS_ENUM, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), OPTIONS_VALS, g_param_spec_enum ("vals", "vals", "vals", OPTIONS_TYPE_VALUES, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 360 "EnumerationTest.c"
}


static void options_instance_init (Options * self) {
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	self->priv = OPTIONS_GET_PRIVATE (self);
#line 367 "EnumerationTest.c"
}


static void options_finalize (GObject* obj) {
	Options * self;
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_OPTIONS, Options);
#line 40 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	_g_free0 (self->priv->_test);
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	G_OBJECT_CLASS (options_parent_class)->finalize (obj);
#line 379 "EnumerationTest.c"
}


GType options_get_type (void) {
	static volatile gsize options_type_id__volatile = 0;
	if (g_once_init_enter (&options_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (OptionsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) options_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Options), 0, (GInstanceInitFunc) options_instance_init, NULL };
		GType options_type_id;
		options_type_id = g_type_register_static (TYPE_OBJECT_MODEL, "Options", &g_define_type_info, 0);
		g_once_init_leave (&options_type_id__volatile, options_type_id);
	}
	return options_type_id__volatile;
}


static void _vala_options_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	Options * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_OPTIONS, Options);
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	switch (property_id) {
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		case OPTIONS_TEST:
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		g_value_set_string (value, options_get_test (self));
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		break;
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		case OPTIONS_OPTIONS:
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		g_value_set_enum (value, options_get_options (self));
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		break;
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		case OPTIONS_VALS:
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		g_value_set_enum (value, options_get_vals (self));
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		break;
#line 418 "EnumerationTest.c"
		default:
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		break;
#line 424 "EnumerationTest.c"
	}
}


static void _vala_options_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	Options * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_OPTIONS, Options);
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	switch (property_id) {
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		case OPTIONS_TEST:
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		options_set_test (self, g_value_get_string (value));
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		break;
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		case OPTIONS_OPTIONS:
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		options_set_options (self, g_value_get_enum (value));
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		break;
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		case OPTIONS_VALS:
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		options_set_vals (self, g_value_get_enum (value));
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		break;
#line 452 "EnumerationTest.c"
		default:
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 38 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		break;
#line 458 "EnumerationTest.c"
	}
}


static const gchar* string_to_string (const gchar* self) {
	const gchar* result = NULL;
#line 1412 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1413 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	result = self;
#line 1413 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 471 "EnumerationTest.c"
}


static void __lambda77_ (void) {
	Options* e = NULL;
	Options* _tmp0_ = NULL;
	GError * _inner_error_ = NULL;
#line 55 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	_tmp0_ = options_new ();
#line 55 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	e = _tmp0_;
#line 483 "EnumerationTest.c"
	{
		Options* _tmp1_ = NULL;
		Options* _tmp2_ = NULL;
		gchar* s = NULL;
		Options* _tmp3_ = NULL;
		OptionsEnum _tmp4_ = 0;
		OptionsEnum _tmp5_ = 0;
		gchar* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		gchar* _tmp13_ = NULL;
		Options* _tmp14_ = NULL;
		OptionsEnum _tmp15_ = 0;
		OptionsEnum _tmp16_ = 0;
		gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		const gchar* _tmp19_ = NULL;
		gchar* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		const gchar* _tmp28_ = NULL;
		gchar* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
		gchar* _tmp36_ = NULL;
		const gchar* _tmp37_ = NULL;
		GEnumValue* env = NULL;
		GEnumValue* _tmp64_ = NULL;
		GValue v = {0};
		GValue _tmp65_ = {0};
		GEnumValue* _tmp66_ = NULL;
		gint _tmp67_ = 0;
		Options* _tmp68_ = NULL;
		gint _tmp69_ = 0;
		Options* _tmp70_ = NULL;
		OptionsEnum _tmp71_ = 0;
		OptionsEnum _tmp72_ = 0;
#line 57 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp1_ = e;
#line 57 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		options_set_test (_tmp1_, "t1");
#line 58 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp2_ = e;
#line 58 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		options_set_options (_tmp2_, OPTIONS_ENUM_SelectBefore);
#line 59 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp3_ = e;
#line 59 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp4_ = options_get_options (_tmp3_);
#line 59 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp5_ = _tmp4_;
#line 59 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp6_ = gxml_enumeration_get_string (TYPE_OPTIONS_ENUM, (gint) _tmp5_, FALSE, FALSE, &_inner_error_);
#line 59 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		s = _tmp6_;
#line 59 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 539 "EnumerationTest.c"
			goto __catch0_g_error;
		}
#line 60 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp7_ = s;
#line 60 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (g_strcmp0 (_tmp7_, "OPTIONS_ENUM_SelectBefore") != 0) {
#line 546 "EnumerationTest.c"
			FILE* _tmp8_ = NULL;
			const gchar* _tmp9_ = NULL;
			const gchar* _tmp10_ = NULL;
			gchar* _tmp11_ = NULL;
			gchar* _tmp12_ = NULL;
#line 61 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp8_ = stdout;
#line 61 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp9_ = s;
#line 61 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp10_ = string_to_string (_tmp9_);
#line 61 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp11_ = g_strconcat ("ERROR: Bad Enum stringification: ", _tmp10_, NULL);
#line 61 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp12_ = _tmp11_;
#line 61 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			fprintf (_tmp8_, "%s", _tmp12_);
#line 61 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp12_);
#line 62 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			g_assert_not_reached ();
#line 568 "EnumerationTest.c"
		}
#line 64 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp14_ = e;
#line 64 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp15_ = options_get_options (_tmp14_);
#line 64 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp16_ = _tmp15_;
#line 64 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp17_ = gxml_enumeration_get_nick (TYPE_OPTIONS_ENUM, (gint) _tmp16_, &_inner_error_);
#line 64 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp13_ = _tmp17_;
#line 64 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 64 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (s);
#line 584 "EnumerationTest.c"
			goto __catch0_g_error;
		}
#line 64 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp18_ = _tmp13_;
#line 64 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp13_ = NULL;
#line 64 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (s);
#line 64 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		s = _tmp18_;
#line 65 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp19_ = s;
#line 65 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (g_strcmp0 (_tmp19_, "selectbefore") != 0) {
#line 599 "EnumerationTest.c"
			FILE* _tmp20_ = NULL;
			const gchar* _tmp21_ = NULL;
			const gchar* _tmp22_ = NULL;
			gchar* _tmp23_ = NULL;
			gchar* _tmp24_ = NULL;
#line 66 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp20_ = stdout;
#line 66 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp21_ = s;
#line 66 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp22_ = string_to_string (_tmp21_);
#line 66 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp23_ = g_strconcat ("ERROR: Bad Enum nick name: ", _tmp22_, NULL);
#line 66 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp24_ = _tmp23_;
#line 66 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			fprintf (_tmp20_, "%s", _tmp24_);
#line 66 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp24_);
#line 67 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			g_assert_not_reached ();
#line 621 "EnumerationTest.c"
		}
#line 69 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp26_ = gxml_enumeration_get_nick (TYPE_OPTIONS_ENUM, (gint) OPTIONS_ENUM_NORMAL_OPERATION, &_inner_error_);
#line 69 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp25_ = _tmp26_;
#line 69 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 69 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp13_);
#line 69 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (s);
#line 633 "EnumerationTest.c"
			goto __catch0_g_error;
		}
#line 69 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp27_ = _tmp25_;
#line 69 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp25_ = NULL;
#line 69 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (s);
#line 69 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		s = _tmp27_;
#line 70 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp28_ = s;
#line 70 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (g_strcmp0 (_tmp28_, "normal-operation") != 0) {
#line 648 "EnumerationTest.c"
			FILE* _tmp29_ = NULL;
			const gchar* _tmp30_ = NULL;
			const gchar* _tmp31_ = NULL;
			gchar* _tmp32_ = NULL;
			gchar* _tmp33_ = NULL;
#line 71 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp29_ = stdout;
#line 71 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp30_ = s;
#line 71 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp31_ = string_to_string (_tmp30_);
#line 71 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp32_ = g_strconcat ("ERROR: Bad Enum nick name: ", _tmp31_, NULL);
#line 71 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp33_ = _tmp32_;
#line 71 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			fprintf (_tmp29_, "%s", _tmp33_);
#line 71 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp33_);
#line 72 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			g_assert_not_reached ();
#line 670 "EnumerationTest.c"
		}
#line 74 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp35_ = gxml_enumeration_get_nick_camelcase (TYPE_OPTIONS_ENUM, (gint) OPTIONS_ENUM_NORMAL_OPERATION, &_inner_error_);
#line 74 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp34_ = _tmp35_;
#line 74 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 74 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp25_);
#line 74 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp13_);
#line 74 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (s);
#line 684 "EnumerationTest.c"
			goto __catch0_g_error;
		}
#line 74 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp36_ = _tmp34_;
#line 74 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp34_ = NULL;
#line 74 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (s);
#line 74 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		s = _tmp36_;
#line 75 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp37_ = s;
#line 75 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (g_strcmp0 (_tmp37_, "NormalOperation") != 0) {
#line 699 "EnumerationTest.c"
			FILE* _tmp38_ = NULL;
			const gchar* _tmp39_ = NULL;
			const gchar* _tmp40_ = NULL;
			gchar* _tmp41_ = NULL;
			gchar* _tmp42_ = NULL;
#line 76 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp38_ = stdout;
#line 76 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp39_ = s;
#line 76 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp40_ = string_to_string (_tmp39_);
#line 76 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp41_ = g_strconcat ("ERROR: Bad Enum nick name: ", _tmp40_, NULL);
#line 76 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp42_ = _tmp41_;
#line 76 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			fprintf (_tmp38_, "%s", _tmp42_);
#line 76 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp42_);
#line 77 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			g_assert_not_reached ();
#line 721 "EnumerationTest.c"
		}
		{
			GEnumValue* _tmp43_ = NULL;
			GEnumValue* _tmp44_ = NULL;
#line 80 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp43_ = gxml_enumeration_parse (TYPE_OPTIONS_ENUM, "selectbefore", &_inner_error_);
#line 80 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp44_ = _tmp43_;
#line 80 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp44_);
#line 80 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 734 "EnumerationTest.c"
				goto __catch1_g_error;
			}
		}
		goto __finally1;
		__catch1_g_error:
		{
			GError* e = NULL;
			FILE* _tmp45_ = NULL;
			const gchar* _tmp46_ = NULL;
			const gchar* _tmp47_ = NULL;
			gchar* _tmp48_ = NULL;
			gchar* _tmp49_ = NULL;
#line 79 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			e = _inner_error_;
#line 79 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_inner_error_ = NULL;
#line 83 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp45_ = stdout;
#line 83 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp46_ = e->message;
#line 83 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp47_ = string_to_string (_tmp46_);
#line 83 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp48_ = g_strconcat ("ERROR PARSING selectbefore: ", _tmp47_, NULL);
#line 83 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp49_ = _tmp48_;
#line 83 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			fprintf (_tmp45_, "%s", _tmp49_);
#line 83 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp49_);
#line 84 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			g_assert_not_reached ();
#line 79 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_error_free0 (e);
#line 769 "EnumerationTest.c"
		}
		__finally1:
#line 79 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 79 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp34_);
#line 79 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp25_);
#line 79 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp13_);
#line 79 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (s);
#line 782 "EnumerationTest.c"
			goto __catch0_g_error;
		}
		{
			GEnumValue* _tmp50_ = NULL;
			GEnumValue* _tmp51_ = NULL;
#line 87 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp50_ = gxml_enumeration_parse (TYPE_OPTIONS_ENUM, "normal-operation", &_inner_error_);
#line 87 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp51_ = _tmp50_;
#line 87 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp51_);
#line 87 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 796 "EnumerationTest.c"
				goto __catch2_g_error;
			}
		}
		goto __finally2;
		__catch2_g_error:
		{
			GError* e = NULL;
			FILE* _tmp52_ = NULL;
			const gchar* _tmp53_ = NULL;
			const gchar* _tmp54_ = NULL;
			gchar* _tmp55_ = NULL;
			gchar* _tmp56_ = NULL;
#line 86 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			e = _inner_error_;
#line 86 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_inner_error_ = NULL;
#line 90 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp52_ = stdout;
#line 90 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp53_ = e->message;
#line 90 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp54_ = string_to_string (_tmp53_);
#line 90 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp55_ = g_strconcat ("ERROR PARSING normal-operation: ", _tmp54_, NULL);
#line 90 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp56_ = _tmp55_;
#line 90 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			fprintf (_tmp52_, "%s", _tmp56_);
#line 90 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp56_);
#line 91 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			g_assert_not_reached ();
#line 86 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_error_free0 (e);
#line 831 "EnumerationTest.c"
		}
		__finally2:
#line 86 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 86 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp34_);
#line 86 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp25_);
#line 86 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp13_);
#line 86 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (s);
#line 844 "EnumerationTest.c"
			goto __catch0_g_error;
		}
		{
			GEnumValue* _tmp57_ = NULL;
			GEnumValue* _tmp58_ = NULL;
#line 94 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp57_ = gxml_enumeration_parse (TYPE_OPTIONS_ENUM, "NormalOperation", &_inner_error_);
#line 94 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp58_ = _tmp57_;
#line 94 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp58_);
#line 94 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 858 "EnumerationTest.c"
				goto __catch3_g_error;
			}
		}
		goto __finally3;
		__catch3_g_error:
		{
			GError* e = NULL;
			FILE* _tmp59_ = NULL;
			const gchar* _tmp60_ = NULL;
			const gchar* _tmp61_ = NULL;
			gchar* _tmp62_ = NULL;
			gchar* _tmp63_ = NULL;
#line 93 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			e = _inner_error_;
#line 93 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_inner_error_ = NULL;
#line 97 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp59_ = stdout;
#line 97 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp60_ = e->message;
#line 97 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp61_ = string_to_string (_tmp60_);
#line 97 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp62_ = g_strconcat ("ERROR PARSING NormalOperation: ", _tmp61_, NULL);
#line 97 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp63_ = _tmp62_;
#line 97 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			fprintf (_tmp59_, "%s", _tmp63_);
#line 97 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp63_);
#line 98 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			g_assert_not_reached ();
#line 93 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_error_free0 (e);
#line 893 "EnumerationTest.c"
		}
		__finally3:
#line 93 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 93 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp34_);
#line 93 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp25_);
#line 93 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp13_);
#line 93 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (s);
#line 906 "EnumerationTest.c"
			goto __catch0_g_error;
		}
#line 100 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp64_ = gxml_enumeration_parse (TYPE_OPTIONS_ENUM, "NormalOperation", &_inner_error_);
#line 100 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		env = _tmp64_;
#line 100 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 100 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp34_);
#line 100 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp25_);
#line 100 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp13_);
#line 100 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (s);
#line 923 "EnumerationTest.c"
			goto __catch0_g_error;
		}
#line 101 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		g_value_init (&_tmp65_, G_TYPE_INT);
#line 101 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		v = _tmp65_;
#line 102 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp66_ = env;
#line 102 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp67_ = (*_tmp66_).value;
#line 102 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		g_value_set_int (&v, _tmp67_);
#line 103 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp68_ = e;
#line 103 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp69_ = g_value_get_int (&v);
#line 103 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		options_set_options (_tmp68_, (OptionsEnum) _tmp69_);
#line 104 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp70_ = e;
#line 104 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp71_ = options_get_options (_tmp70_);
#line 104 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp72_ = _tmp71_;
#line 104 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (_tmp72_ != OPTIONS_ENUM_NORMAL_OPERATION) {
#line 950 "EnumerationTest.c"
			FILE* _tmp73_ = NULL;
			Options* _tmp74_ = NULL;
			OptionsEnum _tmp75_ = 0;
			OptionsEnum _tmp76_ = 0;
			GEnumValue* _tmp77_;
			gchar* _tmp78_ = NULL;
			gchar* _tmp79_ = NULL;
#line 105 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp73_ = stdout;
#line 105 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp74_ = e;
#line 105 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp75_ = options_get_options (_tmp74_);
#line 105 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp76_ = _tmp75_;
#line 105 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp77_ = g_enum_get_value (g_type_class_ref (TYPE_OPTIONS_ENUM), _tmp76_);
#line 105 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp78_ = g_strconcat ("ERROR: setting NormalOperation: ", (_tmp77_ != NULL) ? _tmp77_->value_name : NULL, NULL);
#line 105 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp79_ = _tmp78_;
#line 105 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			fprintf (_tmp73_, "%s", _tmp79_);
#line 105 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp79_);
#line 106 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			g_assert_not_reached ();
#line 978 "EnumerationTest.c"
		}
#line 56 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
#line 56 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (env);
#line 56 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (_tmp34_);
#line 56 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (_tmp25_);
#line 56 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (_tmp13_);
#line 56 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (s);
#line 992 "EnumerationTest.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		FILE* _tmp80_ = NULL;
		const gchar* _tmp81_ = NULL;
		const gchar* _tmp82_ = NULL;
		gchar* _tmp83_ = NULL;
		gchar* _tmp84_ = NULL;
#line 56 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		e = _inner_error_;
#line 56 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_inner_error_ = NULL;
#line 110 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp80_ = stdout;
#line 110 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp81_ = e->message;
#line 110 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp82_ = string_to_string (_tmp81_);
#line 110 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp83_ = g_strconcat ("Error: ", _tmp82_, NULL);
#line 110 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp84_ = _tmp83_;
#line 110 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		fprintf (_tmp80_, "%s", _tmp84_);
#line 110 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (_tmp84_);
#line 111 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		g_assert_not_reached ();
#line 56 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_error_free0 (e);
#line 1025 "EnumerationTest.c"
	}
	__finally0:
#line 56 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 56 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (e);
#line 56 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 56 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		g_clear_error (&_inner_error_);
#line 56 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		return;
#line 1038 "EnumerationTest.c"
	}
#line 54 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	_g_object_unref0 (e);
#line 1042 "EnumerationTest.c"
}


static void ___lambda77__gtest_func (void) {
#line 53 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	__lambda77_ ();
#line 1049 "EnumerationTest.c"
}


static gchar* bool_to_string (gboolean self) {
	gchar* result = NULL;
#line 37 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	if (self) {
#line 1057 "EnumerationTest.c"
		gchar* _tmp0_ = NULL;
#line 38 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp0_ = g_strdup ("true");
#line 38 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
		result = _tmp0_;
#line 38 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
		return result;
#line 1065 "EnumerationTest.c"
	} else {
		gchar* _tmp1_ = NULL;
#line 40 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp1_ = g_strdup ("false");
#line 40 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
		result = _tmp1_;
#line 40 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
		return result;
#line 1074 "EnumerationTest.c"
	}
}


static void __lambda78_ (void) {
	GXmlGDocument* doc = NULL;
	GXmlGDocument* _tmp0_ = NULL;
	Options* options = NULL;
	Options* _tmp1_ = NULL;
	Options* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
#line 116 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	_tmp0_ = gxml_gdocument_new ();
#line 116 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	doc = _tmp0_;
#line 117 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	_tmp1_ = options_new ();
#line 117 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	options = _tmp1_;
#line 118 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	_tmp2_ = options;
#line 118 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	options_set_options (_tmp2_, OPTIONS_ENUM_NORMAL_OPERATION);
#line 1098 "EnumerationTest.c"
	{
		Options* _tmp3_ = NULL;
		GXmlGDocument* _tmp4_ = NULL;
		GXmlNode* _tmp5_ = NULL;
		GXmlNode* _tmp6_ = NULL;
		GXmlGDocument* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		GXmlGDocument* _tmp14_ = NULL;
		GXmlNode* _tmp15_ = NULL;
		GXmlNode* _tmp16_ = NULL;
		GXmlNode* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		GXmlGDocument* _tmp22_ = NULL;
		GXmlNode* _tmp23_ = NULL;
		GXmlNode* _tmp24_ = NULL;
		GXmlNode* _tmp25_ = NULL;
		GXmlGDocument* _tmp26_ = NULL;
		GXmlNode* _tmp27_ = NULL;
		GXmlNode* _tmp28_ = NULL;
		GXmlNode* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		GXmlElement* element = NULL;
		GXmlGDocument* _tmp33_ = NULL;
		GXmlNode* _tmp34_ = NULL;
		GXmlNode* _tmp35_ = NULL;
		GXmlNode* op = NULL;
		GXmlElement* _tmp36_ = NULL;
		GXmlNode* _tmp37_ = NULL;
		GXmlNode* _tmp38_ = NULL;
		GXmlNode* _tmp39_ = NULL;
		gchar* _tmp40_ = NULL;
		gchar* _tmp41_ = NULL;
		gchar* _tmp42_ = NULL;
		Options* _tmp43_ = NULL;
		GXmlGDocument* doc2 = NULL;
		GXmlGDocument* _tmp44_ = NULL;
		GXmlGDocument* _tmp45_ = NULL;
		GXmlNode* _tmp46_ = NULL;
		GXmlNode* _tmp47_ = NULL;
		GXmlNode* _tmp48_ = NULL;
		Options* _tmp49_ = NULL;
		GXmlGDocument* _tmp50_ = NULL;
		GXmlNode* _tmp51_ = NULL;
		GXmlNode* _tmp52_ = NULL;
		GXmlNode* opts = NULL;
		GXmlGDocument* _tmp53_ = NULL;
		GXmlNode* _tmp54_ = NULL;
		GXmlNode* _tmp55_ = NULL;
		GXmlElement* _tmp56_ = NULL;
		GXmlElement* _tmp57_ = NULL;
		GXmlNode* _tmp58_ = NULL;
		GXmlNode* _tmp59_ = NULL;
#line 120 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		g_test_message ("Before serialize...");
#line 121 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp3_ = options;
#line 121 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp4_ = doc;
#line 121 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp5_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp3_, (GXmlNode*) _tmp4_, &_inner_error_);
#line 121 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp6_ = _tmp5_;
#line 121 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (_tmp6_);
#line 121 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1175 "EnumerationTest.c"
			goto __catch4_g_error;
		}
#line 122 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp7_ = doc;
#line 122 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp8_ = gxml_gnode_to_string ((GXmlGNode*) _tmp7_);
#line 122 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp9_ = _tmp8_;
#line 122 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp10_ = g_strconcat ("doc: ", _tmp9_, NULL);
#line 122 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp11_ = _tmp10_;
#line 122 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp12_ = g_strconcat (_tmp11_, " Root?", NULL);
#line 122 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp13_ = _tmp12_;
#line 122 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp14_ = doc;
#line 122 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp15_ = gxml_document_get_root ((GXmlDocument*) _tmp14_);
#line 122 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp16_ = _tmp15_;
#line 122 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp17_ = _tmp16_;
#line 122 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp18_ = bool_to_string (_tmp17_ != NULL);
#line 122 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp19_ = _tmp18_;
#line 122 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp20_ = g_strconcat (_tmp13_, _tmp19_, NULL);
#line 122 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp21_ = _tmp20_;
#line 122 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		g_test_message ("%s", _tmp21_);
#line 122 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (_tmp21_);
#line 122 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (_tmp19_);
#line 122 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (_tmp17_);
#line 122 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (_tmp13_);
#line 122 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (_tmp11_);
#line 122 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (_tmp9_);
#line 123 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp22_ = doc;
#line 123 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp23_ = gxml_document_get_root ((GXmlDocument*) _tmp22_);
#line 123 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp24_ = _tmp23_;
#line 123 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp25_ = _tmp24_;
#line 123 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_vala_assert (_tmp25_ != NULL, "doc.root != null");
#line 123 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (_tmp25_);
#line 124 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp26_ = doc;
#line 124 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp27_ = gxml_document_get_root ((GXmlDocument*) _tmp26_);
#line 124 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp28_ = _tmp27_;
#line 124 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp29_ = _tmp28_;
#line 124 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp30_ = gxml_node_get_name (_tmp29_);
#line 124 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp31_ = _tmp30_;
#line 124 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp32_ = _tmp31_;
#line 124 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_vala_assert (g_strcmp0 (_tmp32_, "options") == 0, "doc.root.name == \"options\"");
#line 124 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (_tmp32_);
#line 124 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (_tmp29_);
#line 125 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp33_ = doc;
#line 125 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp34_ = gxml_document_get_root ((GXmlDocument*) _tmp33_);
#line 125 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp35_ = _tmp34_;
#line 125 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		element = G_TYPE_CHECK_INSTANCE_CAST (_tmp35_, GXML_TYPE_ELEMENT, GXmlElement);
#line 126 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp36_ = element;
#line 126 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp37_ = gxml_element_get_attr (_tmp36_, "options");
#line 126 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		op = _tmp37_;
#line 127 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp38_ = op;
#line 127 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_vala_assert (_tmp38_ != NULL, "op != null");
#line 128 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp39_ = op;
#line 128 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp40_ = gxml_node_get_value (_tmp39_);
#line 128 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp41_ = _tmp40_;
#line 128 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp42_ = _tmp41_;
#line 128 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_vala_assert (g_strcmp0 (_tmp42_, "NormalOperation") == 0, "op.value == \"NormalOperation\"");
#line 128 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (_tmp42_);
#line 129 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp43_ = options;
#line 129 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		options_set_options (_tmp43_, (OptionsEnum) -1);
#line 130 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp44_ = gxml_gdocument_new ();
#line 130 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		doc2 = _tmp44_;
#line 131 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp45_ = doc;
#line 131 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp46_ = gxml_document_get_root ((GXmlDocument*) _tmp45_);
#line 131 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp47_ = _tmp46_;
#line 131 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp48_ = _tmp47_;
#line 131 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_vala_assert (_tmp48_ != NULL, "doc.root != null");
#line 131 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (_tmp48_);
#line 132 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp49_ = options;
#line 132 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp50_ = doc2;
#line 132 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp51_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp49_, (GXmlNode*) _tmp50_, &_inner_error_);
#line 132 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp52_ = _tmp51_;
#line 132 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (_tmp52_);
#line 132 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 132 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 132 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (op);
#line 132 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (element);
#line 1322 "EnumerationTest.c"
			goto __catch4_g_error;
		}
#line 133 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp53_ = doc2;
#line 133 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp54_ = gxml_document_get_root ((GXmlDocument*) _tmp53_);
#line 133 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp55_ = _tmp54_;
#line 133 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp56_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp55_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp55_) : NULL;
#line 133 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (_tmp56_ == NULL) {
#line 133 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (_tmp55_);
#line 1337 "EnumerationTest.c"
		}
#line 133 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp57_ = _tmp56_;
#line 133 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp58_ = gxml_element_get_attr (_tmp57_, "options");
#line 133 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp59_ = _tmp58_;
#line 133 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (_tmp57_);
#line 133 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		opts = _tmp59_;
#line 134 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_vala_assert (opts == NULL, "opts == null");
#line 119 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (opts);
#line 119 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (doc2);
#line 119 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (op);
#line 119 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (element);
#line 1359 "EnumerationTest.c"
	}
	goto __finally4;
	__catch4_g_error:
	{
		GError* e = NULL;
		FILE* _tmp60_ = NULL;
		const gchar* _tmp61_ = NULL;
		const gchar* _tmp62_ = NULL;
		gchar* _tmp63_ = NULL;
		gchar* _tmp64_ = NULL;
#line 119 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		e = _inner_error_;
#line 119 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_inner_error_ = NULL;
#line 137 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp60_ = stdout;
#line 137 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp61_ = e->message;
#line 137 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp62_ = string_to_string (_tmp61_);
#line 137 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp63_ = g_strconcat ("Error: ", _tmp62_, NULL);
#line 137 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp64_ = _tmp63_;
#line 137 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		fprintf (_tmp60_, "%s", _tmp64_);
#line 137 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (_tmp64_);
#line 138 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		g_assert_not_reached ();
#line 119 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_error_free0 (e);
#line 1392 "EnumerationTest.c"
	}
	__finally4:
#line 119 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 119 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (options);
#line 119 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (doc);
#line 119 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 119 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		g_clear_error (&_inner_error_);
#line 119 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		return;
#line 1407 "EnumerationTest.c"
	}
#line 115 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	_g_object_unref0 (options);
#line 115 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	_g_object_unref0 (doc);
#line 1413 "EnumerationTest.c"
}


static void ___lambda78__gtest_func (void) {
#line 114 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	__lambda78_ ();
#line 1420 "EnumerationTest.c"
}


static void __lambda79_ (void) {
	Options* options = NULL;
	Options* _tmp0_ = NULL;
	GError * _inner_error_ = NULL;
#line 143 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	_tmp0_ = options_new ();
#line 143 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	options = _tmp0_;
#line 1432 "EnumerationTest.c"
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		Options* _tmp2_ = NULL;
		GXmlGDocument* _tmp3_ = NULL;
		Options* _tmp4_ = NULL;
		OptionsEnum _tmp5_ = 0;
		OptionsEnum _tmp6_ = 0;
		GXmlGDocument* doc2 = NULL;
		GXmlGDocument* _tmp17_ = NULL;
		Options* _tmp18_ = NULL;
		GXmlGDocument* _tmp19_ = NULL;
		Options* _tmp20_ = NULL;
		OptionsEnum _tmp21_ = 0;
		OptionsEnum _tmp22_ = 0;
		GXmlGDocument* doc3 = NULL;
		GXmlGDocument* _tmp33_ = NULL;
		Options* _tmp34_ = NULL;
		GXmlGDocument* _tmp35_ = NULL;
		Options* _tmp36_ = NULL;
		OptionsEnum _tmp37_ = 0;
		OptionsEnum _tmp38_ = 0;
		GXmlGDocument* doc4 = NULL;
		GXmlGDocument* _tmp49_ = NULL;
		Options* _tmp50_ = NULL;
		GXmlGDocument* _tmp51_ = NULL;
		Options* _tmp52_ = NULL;
		OptionsEnum _tmp53_ = 0;
		OptionsEnum _tmp54_ = 0;
		GXmlGDocument* doc5 = NULL;
		GXmlGDocument* _tmp65_ = NULL;
		Options* _tmp66_ = NULL;
		GXmlGDocument* _tmp67_ = NULL;
		Options* _tmp68_ = NULL;
		OptionsEnum _tmp69_ = 0;
		OptionsEnum _tmp70_ = 0;
		GXmlGDocument* doc6 = NULL;
		GXmlGDocument* _tmp81_ = NULL;
		Options* _tmp82_ = NULL;
		GXmlGDocument* _tmp83_ = NULL;
		Options* _tmp84_ = NULL;
		OptionsEnum _tmp85_ = 0;
		OptionsEnum _tmp86_ = 0;
		GXmlGDocument* doc7 = NULL;
		GXmlGDocument* _tmp87_ = NULL;
		Options* _tmp88_ = NULL;
		GXmlGDocument* _tmp89_ = NULL;
		Options* _tmp90_ = NULL;
		OptionsEnum _tmp91_ = 0;
		OptionsEnum _tmp92_ = 0;
		Options* op2 = NULL;
		Options* _tmp103_ = NULL;
		GXmlGDocument* doc8 = NULL;
		GXmlGDocument* _tmp104_ = NULL;
		Options* _tmp105_ = NULL;
		GXmlGDocument* _tmp106_ = NULL;
		Options* _tmp107_ = NULL;
		OptionsEnum _tmp108_ = 0;
		OptionsEnum _tmp109_ = 0;
#line 145 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <options options=\"NormalOperation\"/>", 0, &_inner_error_);
#line 145 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		doc = _tmp1_;
#line 145 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1498 "EnumerationTest.c"
			goto __catch5_g_error;
		}
#line 147 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp2_ = options;
#line 147 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp3_ = doc;
#line 147 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error_);
#line 147 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 147 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1511 "EnumerationTest.c"
			goto __catch5_g_error;
		}
#line 148 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp4_ = options;
#line 148 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp5_ = options_get_options (_tmp4_);
#line 148 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp6_ = _tmp5_;
#line 148 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (_tmp6_ != OPTIONS_ENUM_NORMAL_OPERATION) {
#line 1522 "EnumerationTest.c"
			FILE* _tmp7_ = NULL;
			Options* _tmp8_ = NULL;
			OptionsEnum _tmp9_ = 0;
			OptionsEnum _tmp10_ = 0;
			GEnumValue* _tmp11_;
			GXmlGDocument* _tmp12_ = NULL;
			gchar* _tmp13_ = NULL;
			gchar* _tmp14_ = NULL;
			gchar* _tmp15_ = NULL;
			gchar* _tmp16_ = NULL;
#line 149 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp7_ = stdout;
#line 149 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp8_ = options;
#line 149 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp9_ = options_get_options (_tmp8_);
#line 149 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp10_ = _tmp9_;
#line 149 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp11_ = g_enum_get_value (g_type_class_ref (TYPE_OPTIONS_ENUM), _tmp10_);
#line 149 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp12_ = doc;
#line 149 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp13_ = gxml_gnode_to_string ((GXmlGNode*) _tmp12_);
#line 149 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp14_ = _tmp13_;
#line 149 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp15_ = g_strconcat ("ERROR: Bad value to options property: ", (_tmp11_ != NULL) ? _tmp11_->value_name : NULL, "\n", _tmp14_, NULL);
#line 149 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp16_ = _tmp15_;
#line 149 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			fprintf (_tmp7_, "%s", _tmp16_);
#line 149 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp16_);
#line 149 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp14_);
#line 150 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			g_assert_not_reached ();
#line 1561 "EnumerationTest.c"
		}
#line 152 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp17_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <options options=\"normal-operation\"/>", 0, &_inner_error_);
#line 152 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		doc2 = _tmp17_;
#line 152 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 152 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1571 "EnumerationTest.c"
			goto __catch5_g_error;
		}
#line 154 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp18_ = options;
#line 154 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp19_ = doc2;
#line 154 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp18_, (GXmlNode*) _tmp19_, &_inner_error_);
#line 154 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 154 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 154 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1586 "EnumerationTest.c"
			goto __catch5_g_error;
		}
#line 155 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp20_ = options;
#line 155 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp21_ = options_get_options (_tmp20_);
#line 155 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp22_ = _tmp21_;
#line 155 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (_tmp22_ != OPTIONS_ENUM_NORMAL_OPERATION) {
#line 1597 "EnumerationTest.c"
			FILE* _tmp23_ = NULL;
			Options* _tmp24_ = NULL;
			OptionsEnum _tmp25_ = 0;
			OptionsEnum _tmp26_ = 0;
			GEnumValue* _tmp27_;
			GXmlGDocument* _tmp28_ = NULL;
			gchar* _tmp29_ = NULL;
			gchar* _tmp30_ = NULL;
			gchar* _tmp31_ = NULL;
			gchar* _tmp32_ = NULL;
#line 156 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp23_ = stdout;
#line 156 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp24_ = options;
#line 156 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp25_ = options_get_options (_tmp24_);
#line 156 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp26_ = _tmp25_;
#line 156 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp27_ = g_enum_get_value (g_type_class_ref (TYPE_OPTIONS_ENUM), _tmp26_);
#line 156 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp28_ = doc2;
#line 156 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp29_ = gxml_gnode_to_string ((GXmlGNode*) _tmp28_);
#line 156 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp30_ = _tmp29_;
#line 156 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp31_ = g_strconcat ("ERROR: Bad value to options property: ", (_tmp27_ != NULL) ? _tmp27_->value_name : NULL, "\n", _tmp30_, NULL);
#line 156 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp32_ = _tmp31_;
#line 156 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			fprintf (_tmp23_, "%s", _tmp32_);
#line 156 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp32_);
#line 156 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp30_);
#line 157 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			g_assert_not_reached ();
#line 1636 "EnumerationTest.c"
		}
#line 159 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp33_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <options options=\"selectbefore\"/>", 0, &_inner_error_);
#line 159 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		doc3 = _tmp33_;
#line 159 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 159 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 159 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1648 "EnumerationTest.c"
			goto __catch5_g_error;
		}
#line 161 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp34_ = options;
#line 161 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp35_ = doc3;
#line 161 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp34_, (GXmlNode*) _tmp35_, &_inner_error_);
#line 161 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 161 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc3);
#line 161 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 161 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1665 "EnumerationTest.c"
			goto __catch5_g_error;
		}
#line 162 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp36_ = options;
#line 162 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp37_ = options_get_options (_tmp36_);
#line 162 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp38_ = _tmp37_;
#line 162 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (_tmp38_ != OPTIONS_ENUM_SelectBefore) {
#line 1676 "EnumerationTest.c"
			FILE* _tmp39_ = NULL;
			Options* _tmp40_ = NULL;
			OptionsEnum _tmp41_ = 0;
			OptionsEnum _tmp42_ = 0;
			GEnumValue* _tmp43_;
			GXmlGDocument* _tmp44_ = NULL;
			gchar* _tmp45_ = NULL;
			gchar* _tmp46_ = NULL;
			gchar* _tmp47_ = NULL;
			gchar* _tmp48_ = NULL;
#line 163 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp39_ = stdout;
#line 163 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp40_ = options;
#line 163 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp41_ = options_get_options (_tmp40_);
#line 163 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp42_ = _tmp41_;
#line 163 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp43_ = g_enum_get_value (g_type_class_ref (TYPE_OPTIONS_ENUM), _tmp42_);
#line 163 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp44_ = doc3;
#line 163 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp45_ = gxml_gnode_to_string ((GXmlGNode*) _tmp44_);
#line 163 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp46_ = _tmp45_;
#line 163 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp47_ = g_strconcat ("ERROR: Bad value to options property: ", (_tmp43_ != NULL) ? _tmp43_->value_name : NULL, "\n", _tmp46_, NULL);
#line 163 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp48_ = _tmp47_;
#line 163 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			fprintf (_tmp39_, "%s", _tmp48_);
#line 163 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp48_);
#line 163 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp46_);
#line 164 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			g_assert_not_reached ();
#line 1715 "EnumerationTest.c"
		}
#line 166 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp49_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <options options=\"OPTIONS_ENUM_SelectBefore\"/" \
">", 0, &_inner_error_);
#line 166 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		doc4 = _tmp49_;
#line 166 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 166 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc3);
#line 166 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 166 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1729 "EnumerationTest.c"
			goto __catch5_g_error;
		}
#line 168 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp50_ = options;
#line 168 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp51_ = doc4;
#line 168 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp50_, (GXmlNode*) _tmp51_, &_inner_error_);
#line 168 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 168 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc4);
#line 168 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc3);
#line 168 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 168 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1748 "EnumerationTest.c"
			goto __catch5_g_error;
		}
#line 169 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp52_ = options;
#line 169 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp53_ = options_get_options (_tmp52_);
#line 169 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp54_ = _tmp53_;
#line 169 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (_tmp54_ != OPTIONS_ENUM_SelectBefore) {
#line 1759 "EnumerationTest.c"
			FILE* _tmp55_ = NULL;
			Options* _tmp56_ = NULL;
			OptionsEnum _tmp57_ = 0;
			OptionsEnum _tmp58_ = 0;
			GEnumValue* _tmp59_;
			GXmlGDocument* _tmp60_ = NULL;
			gchar* _tmp61_ = NULL;
			gchar* _tmp62_ = NULL;
			gchar* _tmp63_ = NULL;
			gchar* _tmp64_ = NULL;
#line 170 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp55_ = stdout;
#line 170 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp56_ = options;
#line 170 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp57_ = options_get_options (_tmp56_);
#line 170 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp58_ = _tmp57_;
#line 170 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp59_ = g_enum_get_value (g_type_class_ref (TYPE_OPTIONS_ENUM), _tmp58_);
#line 170 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp60_ = doc4;
#line 170 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp61_ = gxml_gnode_to_string ((GXmlGNode*) _tmp60_);
#line 170 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp62_ = _tmp61_;
#line 170 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp63_ = g_strconcat ("ERROR: Bad value to options property: ", (_tmp59_ != NULL) ? _tmp59_->value_name : NULL, "\n", _tmp62_, NULL);
#line 170 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp64_ = _tmp63_;
#line 170 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			fprintf (_tmp55_, "%s", _tmp64_);
#line 170 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp64_);
#line 170 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp62_);
#line 171 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			g_assert_not_reached ();
#line 1798 "EnumerationTest.c"
		}
#line 173 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp65_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <options options=\"SelectBefore\"/>", 0, &_inner_error_);
#line 173 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		doc5 = _tmp65_;
#line 173 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 173 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc4);
#line 173 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc3);
#line 173 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 173 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1814 "EnumerationTest.c"
			goto __catch5_g_error;
		}
#line 175 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp66_ = options;
#line 175 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp67_ = doc5;
#line 175 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp66_, (GXmlNode*) _tmp67_, &_inner_error_);
#line 175 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 175 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc5);
#line 175 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc4);
#line 175 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc3);
#line 175 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 175 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1835 "EnumerationTest.c"
			goto __catch5_g_error;
		}
#line 176 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp68_ = options;
#line 176 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp69_ = options_get_options (_tmp68_);
#line 176 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp70_ = _tmp69_;
#line 176 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (_tmp70_ != OPTIONS_ENUM_SelectBefore) {
#line 1846 "EnumerationTest.c"
			FILE* _tmp71_ = NULL;
			Options* _tmp72_ = NULL;
			OptionsEnum _tmp73_ = 0;
			OptionsEnum _tmp74_ = 0;
			GEnumValue* _tmp75_;
			GXmlGDocument* _tmp76_ = NULL;
			gchar* _tmp77_ = NULL;
			gchar* _tmp78_ = NULL;
			gchar* _tmp79_ = NULL;
			gchar* _tmp80_ = NULL;
#line 177 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp71_ = stdout;
#line 177 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp72_ = options;
#line 177 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp73_ = options_get_options (_tmp72_);
#line 177 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp74_ = _tmp73_;
#line 177 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp75_ = g_enum_get_value (g_type_class_ref (TYPE_OPTIONS_ENUM), _tmp74_);
#line 177 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp76_ = doc5;
#line 177 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp77_ = gxml_gnode_to_string ((GXmlGNode*) _tmp76_);
#line 177 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp78_ = _tmp77_;
#line 177 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp79_ = g_strconcat ("ERROR: Bad value to options property: ", (_tmp75_ != NULL) ? _tmp75_->value_name : NULL, "\n", _tmp78_, NULL);
#line 177 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp80_ = _tmp79_;
#line 177 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			fprintf (_tmp71_, "%s", _tmp80_);
#line 177 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp80_);
#line 177 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp78_);
#line 178 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			g_assert_not_reached ();
#line 1885 "EnumerationTest.c"
		}
#line 180 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp81_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <options options=\"SELECTBEFORE\"/>", 0, &_inner_error_);
#line 180 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		doc6 = _tmp81_;
#line 180 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 180 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc5);
#line 180 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc4);
#line 180 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc3);
#line 180 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 180 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1903 "EnumerationTest.c"
			goto __catch5_g_error;
		}
#line 182 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp82_ = options;
#line 182 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp83_ = doc6;
#line 182 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp82_, (GXmlNode*) _tmp83_, &_inner_error_);
#line 182 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 182 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc6);
#line 182 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc5);
#line 182 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc4);
#line 182 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc3);
#line 182 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 182 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1926 "EnumerationTest.c"
			goto __catch5_g_error;
		}
#line 183 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp84_ = options;
#line 183 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp85_ = options_get_options (_tmp84_);
#line 183 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp86_ = _tmp85_;
#line 183 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_vala_assert (_tmp86_ == OPTIONS_ENUM_SelectBefore, "options.options == OptionsEnum.SelectBefore");
#line 184 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp87_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <options options=\"NORMAL_OPERATION\"/>", 0, &_inner_error_);
#line 184 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		doc7 = _tmp87_;
#line 184 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 184 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc6);
#line 184 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc5);
#line 184 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc4);
#line 184 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc3);
#line 184 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 184 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1955 "EnumerationTest.c"
			goto __catch5_g_error;
		}
#line 186 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp88_ = options;
#line 186 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp89_ = doc7;
#line 186 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp88_, (GXmlNode*) _tmp89_, &_inner_error_);
#line 186 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 186 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc7);
#line 186 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc6);
#line 186 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc5);
#line 186 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc4);
#line 186 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc3);
#line 186 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 186 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1980 "EnumerationTest.c"
			goto __catch5_g_error;
		}
#line 187 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp90_ = options;
#line 187 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp91_ = options_get_options (_tmp90_);
#line 187 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp92_ = _tmp91_;
#line 187 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (_tmp92_ != OPTIONS_ENUM_SelectBefore) {
#line 1991 "EnumerationTest.c"
			FILE* _tmp93_ = NULL;
			Options* _tmp94_ = NULL;
			OptionsEnum _tmp95_ = 0;
			OptionsEnum _tmp96_ = 0;
			GEnumValue* _tmp97_;
			GXmlGDocument* _tmp98_ = NULL;
			gchar* _tmp99_ = NULL;
			gchar* _tmp100_ = NULL;
			gchar* _tmp101_ = NULL;
			gchar* _tmp102_ = NULL;
#line 188 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp93_ = stdout;
#line 188 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp94_ = options;
#line 188 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp95_ = options_get_options (_tmp94_);
#line 188 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp96_ = _tmp95_;
#line 188 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp97_ = g_enum_get_value (g_type_class_ref (TYPE_OPTIONS_ENUM), _tmp96_);
#line 188 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp98_ = doc7;
#line 188 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp99_ = gxml_gnode_to_string ((GXmlGNode*) _tmp98_);
#line 188 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp100_ = _tmp99_;
#line 188 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp101_ = g_strconcat ("ERROR: Bad value to options property: ", (_tmp97_ != NULL) ? _tmp97_->value_name : NULL, "\n", _tmp100_, NULL);
#line 188 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp102_ = _tmp101_;
#line 188 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			fprintf (_tmp93_, "%s", _tmp102_);
#line 188 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp102_);
#line 188 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp100_);
#line 189 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			g_assert_not_reached ();
#line 2030 "EnumerationTest.c"
		}
#line 191 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp103_ = options_new ();
#line 191 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		op2 = _tmp103_;
#line 192 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp104_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <options options=\"INVALID\"/>", 0, &_inner_error_);
#line 192 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		doc8 = _tmp104_;
#line 192 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 192 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (op2);
#line 192 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc7);
#line 192 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc6);
#line 192 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc5);
#line 192 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc4);
#line 192 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc3);
#line 192 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 192 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 2058 "EnumerationTest.c"
			goto __catch5_g_error;
		}
#line 194 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp105_ = op2;
#line 194 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp106_ = doc8;
#line 194 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp105_, (GXmlNode*) _tmp106_, &_inner_error_);
#line 194 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 194 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc8);
#line 194 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (op2);
#line 194 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc7);
#line 194 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc6);
#line 194 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc5);
#line 194 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc4);
#line 194 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc3);
#line 194 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 194 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 2087 "EnumerationTest.c"
			goto __catch5_g_error;
		}
#line 195 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp107_ = op2;
#line 195 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp108_ = options_get_options (_tmp107_);
#line 195 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp109_ = _tmp108_;
#line 195 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (_tmp109_ != OPTIONS_ENUM_SelectBefore) {
#line 2098 "EnumerationTest.c"
			FILE* _tmp110_ = NULL;
			Options* _tmp111_ = NULL;
			OptionsEnum _tmp112_ = 0;
			OptionsEnum _tmp113_ = 0;
			GEnumValue* _tmp114_;
			GXmlGDocument* _tmp115_ = NULL;
			gchar* _tmp116_ = NULL;
			gchar* _tmp117_ = NULL;
			gchar* _tmp118_ = NULL;
			gchar* _tmp119_ = NULL;
#line 196 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp110_ = stdout;
#line 196 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp111_ = op2;
#line 196 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp112_ = options_get_options (_tmp111_);
#line 196 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp113_ = _tmp112_;
#line 196 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp114_ = g_enum_get_value (g_type_class_ref (TYPE_OPTIONS_ENUM), _tmp113_);
#line 196 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp115_ = doc8;
#line 196 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp116_ = gxml_gnode_to_string ((GXmlGNode*) _tmp115_);
#line 196 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp117_ = _tmp116_;
#line 196 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp118_ = g_strconcat ("ERROR: Bad value to options property: ", (_tmp114_ != NULL) ? _tmp114_->value_name : NULL, "\n", _tmp117_, NULL);
#line 196 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_tmp119_ = _tmp118_;
#line 196 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			fprintf (_tmp110_, "%s", _tmp119_);
#line 196 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp119_);
#line 196 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (_tmp117_);
#line 197 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			g_assert_not_reached ();
#line 2137 "EnumerationTest.c"
		}
#line 144 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (doc8);
#line 144 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (op2);
#line 144 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (doc7);
#line 144 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (doc6);
#line 144 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (doc5);
#line 144 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (doc4);
#line 144 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (doc3);
#line 144 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (doc2);
#line 144 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (doc);
#line 2157 "EnumerationTest.c"
	}
	goto __finally5;
	__catch5_g_error:
	{
		GError* e = NULL;
		FILE* _tmp120_ = NULL;
		const gchar* _tmp121_ = NULL;
		const gchar* _tmp122_ = NULL;
		gchar* _tmp123_ = NULL;
		gchar* _tmp124_ = NULL;
#line 144 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		e = _inner_error_;
#line 144 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_inner_error_ = NULL;
#line 201 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp120_ = stdout;
#line 201 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp121_ = e->message;
#line 201 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp122_ = string_to_string (_tmp121_);
#line 201 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp123_ = g_strconcat ("Error: ", _tmp122_, NULL);
#line 201 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp124_ = _tmp123_;
#line 201 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		fprintf (_tmp120_, "%s", _tmp124_);
#line 201 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (_tmp124_);
#line 202 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		g_assert_not_reached ();
#line 144 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_error_free0 (e);
#line 2190 "EnumerationTest.c"
	}
	__finally5:
#line 144 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 144 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_object_unref0 (options);
#line 144 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 144 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		g_clear_error (&_inner_error_);
#line 144 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		return;
#line 2203 "EnumerationTest.c"
	}
#line 142 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	_g_object_unref0 (options);
#line 2207 "EnumerationTest.c"
}


static void ___lambda79__gtest_func (void) {
#line 141 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	__lambda79_ ();
#line 2214 "EnumerationTest.c"
}


static void __lambda80_ (void) {
	GError * _inner_error_ = NULL;
	{
		GEnumValue* v1 = NULL;
		GEnumValue* _tmp0_ = NULL;
		GEnumValue* _tmp1_ = NULL;
		gint _tmp2_ = 0;
		GEnumValue* v2 = NULL;
		GEnumValue* _tmp3_ = NULL;
		GEnumValue* _tmp4_ = NULL;
		gint _tmp5_ = 0;
		GEnumValue* v3 = NULL;
		GEnumValue* _tmp6_ = NULL;
		GEnumValue* _tmp7_ = NULL;
		gint _tmp8_ = 0;
		GEnumValue* v4 = NULL;
		GEnumValue* _tmp9_ = NULL;
		GEnumValue* _tmp10_ = NULL;
		gint _tmp11_ = 0;
		GEnumValue* v5 = NULL;
		GEnumValue* _tmp12_ = NULL;
		GEnumValue* _tmp13_ = NULL;
		gint _tmp14_ = 0;
		GEnumValue* v6 = NULL;
		GEnumValue* _tmp15_ = NULL;
		GEnumValue* _tmp16_ = NULL;
		gint _tmp17_ = 0;
		GEnumValue* v7 = NULL;
		GEnumValue* _tmp18_ = NULL;
		GEnumValue* _tmp19_ = NULL;
		gint _tmp20_ = 0;
		GEnumValue* v8 = NULL;
		GEnumValue* _tmp21_ = NULL;
		GEnumValue* _tmp22_ = NULL;
		gint _tmp23_ = 0;
		GEnumValue* v9 = NULL;
		GEnumValue* _tmp24_ = NULL;
		GEnumValue* _tmp25_ = NULL;
		gint _tmp26_ = 0;
#line 207 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp0_ = gxml_enumeration_parse (OPTIONS_TYPE_VALUES, "AP", &_inner_error_);
#line 207 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		v1 = _tmp0_;
#line 207 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2263 "EnumerationTest.c"
			goto __catch6_g_error;
		}
#line 208 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp1_ = v1;
#line 208 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp2_ = (*_tmp1_).value;
#line 208 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_vala_assert (_tmp2_ == ((gint) OPTIONS_VALUES_AP), "v1.value == (int) Options.Values.AP");
#line 209 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp3_ = gxml_enumeration_parse (OPTIONS_TYPE_VALUES, "Ap", &_inner_error_);
#line 209 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		v2 = _tmp3_;
#line 209 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 209 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v1);
#line 2280 "EnumerationTest.c"
			goto __catch6_g_error;
		}
#line 210 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp4_ = v2;
#line 210 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp5_ = (*_tmp4_).value;
#line 210 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_vala_assert (_tmp5_ == ((gint) OPTIONS_VALUES_AP), "v2.value == (int) Options.Values.AP");
#line 211 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp6_ = gxml_enumeration_parse (OPTIONS_TYPE_VALUES, "ap", &_inner_error_);
#line 211 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		v3 = _tmp6_;
#line 211 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 211 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v2);
#line 211 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v1);
#line 2299 "EnumerationTest.c"
			goto __catch6_g_error;
		}
#line 212 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp7_ = v3;
#line 212 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp8_ = (*_tmp7_).value;
#line 212 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_vala_assert (_tmp8_ == ((gint) OPTIONS_VALUES_AP), "v3.value == (int) Options.Values.AP");
#line 213 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp9_ = gxml_enumeration_parse (OPTIONS_TYPE_VALUES, "KPVALUE", &_inner_error_);
#line 213 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		v4 = _tmp9_;
#line 213 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 213 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v3);
#line 213 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v2);
#line 213 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v1);
#line 2320 "EnumerationTest.c"
			goto __catch6_g_error;
		}
#line 214 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp10_ = v4;
#line 214 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp11_ = (*_tmp10_).value;
#line 214 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_vala_assert (_tmp11_ == ((gint) OPTIONS_VALUES_KP_VALUE), "v4.value == (int) Options.Values.KP_VALUE");
#line 215 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp12_ = gxml_enumeration_parse (OPTIONS_TYPE_VALUES, "KpValue", &_inner_error_);
#line 215 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		v5 = _tmp12_;
#line 215 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 215 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v4);
#line 215 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v3);
#line 215 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v2);
#line 215 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v1);
#line 2343 "EnumerationTest.c"
			goto __catch6_g_error;
		}
#line 216 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp13_ = v5;
#line 216 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp14_ = (*_tmp13_).value;
#line 216 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_vala_assert (_tmp14_ == ((gint) OPTIONS_VALUES_KP_VALUE), "v5.value == (int) Options.Values.KP_VALUE");
#line 217 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp15_ = gxml_enumeration_parse (OPTIONS_TYPE_VALUES, "kpvalue", &_inner_error_);
#line 217 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		v6 = _tmp15_;
#line 217 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 217 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v5);
#line 217 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v4);
#line 217 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v3);
#line 217 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v2);
#line 217 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v1);
#line 2368 "EnumerationTest.c"
			goto __catch6_g_error;
		}
#line 218 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp16_ = v6;
#line 218 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp17_ = (*_tmp16_).value;
#line 218 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_vala_assert (_tmp17_ == ((gint) OPTIONS_VALUES_KP_VALUE), "v6.value == (int) Options.Values.KP_VALUE");
#line 219 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp18_ = gxml_enumeration_parse (OPTIONS_TYPE_VALUES, "EXTERNALVALUEVISION", &_inner_error_);
#line 219 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		v7 = _tmp18_;
#line 219 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 219 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v6);
#line 219 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v5);
#line 219 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v4);
#line 219 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v3);
#line 219 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v2);
#line 219 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v1);
#line 2395 "EnumerationTest.c"
			goto __catch6_g_error;
		}
#line 220 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp19_ = v7;
#line 220 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp20_ = (*_tmp19_).value;
#line 220 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_vala_assert (_tmp20_ == ((gint) OPTIONS_VALUES_EXTERNAL_VALUE_VISION), "v7.value == (int) Options.Values.EXTERNAL_VALUE_VISION");
#line 221 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp21_ = gxml_enumeration_parse (OPTIONS_TYPE_VALUES, "ExternalValueVision", &_inner_error_);
#line 221 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		v8 = _tmp21_;
#line 221 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 221 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v7);
#line 221 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v6);
#line 221 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v5);
#line 221 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v4);
#line 221 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v3);
#line 221 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v2);
#line 221 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v1);
#line 2424 "EnumerationTest.c"
			goto __catch6_g_error;
		}
#line 222 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp22_ = v8;
#line 222 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp23_ = (*_tmp22_).value;
#line 222 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_vala_assert (_tmp23_ == ((gint) OPTIONS_VALUES_EXTERNAL_VALUE_VISION), "v8.value == (int) Options.Values.EXTERNAL_VALUE_VISION");
#line 223 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp24_ = gxml_enumeration_parse (OPTIONS_TYPE_VALUES, "externalvaluevision", &_inner_error_);
#line 223 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		v9 = _tmp24_;
#line 223 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 223 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v8);
#line 223 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v7);
#line 223 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v6);
#line 223 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v5);
#line 223 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v4);
#line 223 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v3);
#line 223 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v2);
#line 223 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
			_g_free0 (v1);
#line 2455 "EnumerationTest.c"
			goto __catch6_g_error;
		}
#line 224 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp25_ = v9;
#line 224 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp26_ = (*_tmp25_).value;
#line 224 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_vala_assert (_tmp26_ == ((gint) OPTIONS_VALUES_EXTERNAL_VALUE_VISION), "v9.value == (int) Options.Values.EXTERNAL_VALUE_VISION");
#line 206 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (v9);
#line 206 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (v8);
#line 206 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (v7);
#line 206 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (v6);
#line 206 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (v5);
#line 206 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (v4);
#line 206 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (v3);
#line 206 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (v2);
#line 206 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (v1);
#line 2482 "EnumerationTest.c"
	}
	goto __finally6;
	__catch6_g_error:
	{
		GError* e = NULL;
		GError* _tmp27_ = NULL;
		const gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
#line 206 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		e = _inner_error_;
#line 206 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_inner_error_ = NULL;
#line 226 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp27_ = e;
#line 226 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp28_ = _tmp27_->message;
#line 226 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp29_ = g_strconcat ("Parse error: ", _tmp28_, NULL);
#line 226 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp30_ = _tmp29_;
#line 226 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		g_test_message ("%s", _tmp30_);
#line 226 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (_tmp30_);
#line 206 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_error_free0 (e);
#line 2510 "EnumerationTest.c"
	}
	__finally6:
#line 206 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 206 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 206 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		g_clear_error (&_inner_error_);
#line 206 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		return;
#line 2521 "EnumerationTest.c"
	}
}


static void ___lambda80__gtest_func (void) {
#line 205 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	__lambda80_ ();
#line 2529 "EnumerationTest.c"
}


static void __lambda81_ (void) {
	GError * _inner_error_ = NULL;
	{
		gchar** options = NULL;
		gint _tmp0_ = 0;
		gchar** _tmp1_ = NULL;
		gint options_length1 = 0;
		gint _options_size_ = 0;
		const gchar* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 231 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp1_ = gxml_enumeration_to_string_array (OPTIONS_TYPE_VALUES, &_tmp0_, &_inner_error_);
#line 231 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		options = _tmp1_;
#line 231 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		options_length1 = _tmp0_;
#line 231 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_options_size_ = options_length1;
#line 231 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2554 "EnumerationTest.c"
			goto __catch7_g_error;
		}
#line 232 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_vala_assert (options != NULL, "options != null");
#line 233 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_vala_assert (options_length1 == 3, "options.length == 3");
#line 234 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp2_ = options[0];
#line 234 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_vala_assert (g_strcmp0 (_tmp2_, "Ap") == 0, "options[0] == \"Ap\"");
#line 235 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp3_ = options[1];
#line 235 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_vala_assert (g_strcmp0 (_tmp3_, "KpValue") == 0, "options[1] == \"KpValue\"");
#line 236 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp4_ = options[2];
#line 236 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_vala_assert (g_strcmp0 (_tmp4_, "ExternalValueVision") == 0, "options[2] == \"ExternalValueVision\"");
#line 230 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		options = (_vala_array_free (options, options_length1, (GDestroyNotify) g_free), NULL);
#line 2575 "EnumerationTest.c"
	}
	goto __finally7;
	__catch7_g_error:
	{
		GError* e = NULL;
		GError* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
#line 230 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		e = _inner_error_;
#line 230 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_inner_error_ = NULL;
#line 238 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp5_ = e;
#line 238 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp6_ = _tmp5_->message;
#line 238 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp7_ = g_strconcat ("Parse error: ", _tmp6_, NULL);
#line 238 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_tmp8_ = _tmp7_;
#line 238 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		g_test_message ("%s", _tmp8_);
#line 238 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_free0 (_tmp8_);
#line 230 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		_g_error_free0 (e);
#line 2603 "EnumerationTest.c"
	}
	__finally7:
#line 230 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 230 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 230 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		g_clear_error (&_inner_error_);
#line 230 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
		return;
#line 2614 "EnumerationTest.c"
	}
}


static void ___lambda81__gtest_func (void) {
#line 229 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	__lambda81_ ();
#line 2622 "EnumerationTest.c"
}


void serializable_enumeration_test_add_tests (void) {
#line 53 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	g_test_add_func ("/gxml/serializable/enumeration", ___lambda77__gtest_func);
#line 114 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	g_test_add_func ("/gxml/serializable/enumeration-serialize", ___lambda78__gtest_func);
#line 141 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	g_test_add_func ("/gxml/serializable/enumeration-deserialize", ___lambda79__gtest_func);
#line 205 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	g_test_add_func ("/gxml/serializable/enumeration/parse", ___lambda80__gtest_func);
#line 229 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	g_test_add_func ("/gxml/serializable/enumeration/to_string_array", ___lambda81__gtest_func);
#line 2637 "EnumerationTest.c"
}


SerializableEnumerationTest* serializable_enumeration_test_construct (GType object_type) {
	SerializableEnumerationTest* self = NULL;
#line 49 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	self = (SerializableEnumerationTest*) gxml_test_construct (object_type);
#line 49 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	return self;
#line 2647 "EnumerationTest.c"
}


SerializableEnumerationTest* serializable_enumeration_test_new (void) {
#line 49 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	return serializable_enumeration_test_construct (TYPE_SERIALIZABLE_ENUMERATION_TEST);
#line 2654 "EnumerationTest.c"
}


static void serializable_enumeration_test_class_init (SerializableEnumerationTestClass * klass) {
#line 49 "/home/despinosa/Proyectos/gxml/test/EnumerationTest.vala"
	serializable_enumeration_test_parent_class = g_type_class_peek_parent (klass);
#line 2661 "EnumerationTest.c"
}


static void serializable_enumeration_test_instance_init (SerializableEnumerationTest * self) {
}


GType serializable_enumeration_test_get_type (void) {
	static volatile gsize serializable_enumeration_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_enumeration_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableEnumerationTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_enumeration_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableEnumerationTest), 0, (GInstanceInitFunc) serializable_enumeration_test_instance_init, NULL };
		GType serializable_enumeration_test_type_id;
		serializable_enumeration_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializableEnumerationTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_enumeration_test_type_id__volatile, serializable_enumeration_test_type_id);
	}
	return serializable_enumeration_test_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



